Python programs and modules — pywws 12.12_e27456b documentation

### Navigation

- index
- modules |
- next |
- previous |
- pywws 12.12_e27456b documentation »

# Python programs and modules

Contents:

`Hourly` | Get weather data, process it, prepare graphs & text files and upload to a web site.
`LiveLog` | Get weather data, store it, and process it.
`Reprocess` | Regenerate hourly and daily summary data.
`TwitterAuth` | Authorise pywws to post to your Twitter account
`SetWeatherStation` | Set some weather station parameters
`TestWeatherStation` | Test connection to weather station.
`RunModule` | Run a pywws module.
`USBQualityTest` | Test quality of USB connection to weather station
`EWtoPy` | Convert EasyWeather.dat data to pywws format
`pywws.Tasks` | Routines to perform common tasks such as plotting gaphs or uploading files.
`pywws.LogData` | Save weather station history to file
`pywws.Process` | Generate hourly, daily & monthly summaries of raw weather station
`pywws.calib` | Calibrate raw weather station data
`pywws.Plot` | Plot graphs of weather data according to an XML recipe
`pywws.WindRose` | Plot a “wind rose”
`pywws.Template` | Create text data file based on a template.
`pywws.Forecast` | Predict future weather using recent data
`pywws.ZambrettiCore` |
`pywws.Upload` | Upload files to a directory by ftp
`pywws.ToTwitter` | Post a message to Twitter
`pywws.toservice` | Post weather update to services such as Weather Underground
`pywws.YoWindow` | Generate YoWindow XML file
`pywws.WeatherStation` | Get data from WH1080/WH3080 compatible weather stations.
`pywws.device_cython_hidapi` |
`pywws.device_pyusb` | Low level USB interface to weather station, using PyUSB.
`pywws.DataStore` | DataStore.py - stores readings in easy to access files
`pywws.TimeZone` | Provide a couple of datetime.tzinfo() objects representing local
`pywws.Localisation` | Localisation.py - provide translations of strings into local
`pywws.calib` | Calibrate raw weather station data
`pywws.conversions` | conversions.py - a set of functions to convert pywws native units
`pywws.Logger` | Common code for logging info and errors.

### Navigation

- index
- modules |
- next |
- previous |
- pywws 12.12_e27456b documentation »